@@ -14,11 +14,9 @@ class BlogToolbar(CMSToolbar):
         if not (self.is_current_app and self.request.user.has_perm('aldryn_blog.add_post')):
             return
         menu = self.toolbar.get_or_create_menu('blog-app', _('Blog'))
-        menu.add_modal_item(_('Add Blog Post'), reverse('admin:aldryn_blog_post_add'),
-                            close_on_url=reverse('admin:aldryn_blog_post_changelist'))
+        menu.add_modal_item(_('Add Blog Post'), reverse('admin:aldryn_blog_post_add'))
 
         blog_entry = getattr(self.request, request_post_identifier, None)
         if blog_entry and self.request.user.has_perm('aldryn_blog.change_post'):
-            menu.add_modal_item(_('Edit Blog Post'), reverse('admin:aldryn_blog_post_change', args=(
-                blog_entry.pk,)),
-                close_on_url=reverse('admin:aldryn_blog_post_changelist'), active=True)
+            menu.add_modal_item(_('Edit Blog Post'), reverse('admin:aldryn_blog_post_change', args=(blog_entry.pk,)),
+                                active=True)
